referrerpolicy=no-referrer-when-downgrade

PopulateDecimals

Type Alias PopulateDecimals 

pub type PopulateDecimals<T> = VersionedMigration<1, 2, InnerPopulateDecimals<T>, Pallet<T>, <T as Config>::DbWeight>;
Version-gated v1 -> v2 migration that fills in decimal snapshots for all pre-existing external assets and the internal asset, and bumps the pallet on-chain storage version from 1 to 2.

Aliased Type

pub struct PopulateDecimals<T> { /* private fields */ }